@@ -3,7 +3,7 @@ from yahoofinancials import YahooFinancials
 
 from ewah.constants import EWAHConstants as EC
 from ewah.operators.base import EWAHBaseOperator
-from ewah.ewah_utils.airflow_utils import datetime_utcnow_with_tz
+from ewah.utils.airflow_utils import datetime_utcnow_with_tz
 
 
 class EWAHFXOperator(EWAHBaseOperator):
@@ -39,11 +39,9 @@ class EWAHFXOperator(EWAHBaseOperator):
             )
         kwargs["source_conn_id"] = None
         # If incremental, the primary key column is 'date'
-        if kwargs.get("update_on_columns"):
-            self.log.info(
-                "update_on_columns is fixed for this operator. Using the default."
-            )
-        kwargs["update_on_columns"] = ["date"]
+        if kwargs.get("primary_key"):
+            self.log.info("primary_key is fixed for this operator. Using the default.")
+        kwargs["primary_key"] = ["date"]
 
         self.currency_pair = currency_pair
         self.frequency = frequency
