@@ -263,7 +263,10 @@ class EWAHdbtOperator(BaseOperator):
             else:
                 # Different pip behavior since dbt 1.0.0
                 cmd.append(
-                    'pip install --quiet --upgrade "MarkupSafe<=2.0.1" "dbt-{0}{1}"'.format(
+                    "pip install --quiet --upgrade "
+                    '"MarkupSafe<=2.0.1" '
+                    '"dbt-core{1}" '
+                    '"dbt-{0}{1}"'.format(
                         {
                             EC.DWH_ENGINE_POSTGRES: "postgres",
                             EC.DWH_ENGINE_SNOWFLAKE: "snowflake",
